.. _help:

Getting Help
============

.. toctree::
    :maxdepth: 1
    :titlesonly:

    Mailing List / Forum <http://groups.google.com/group/kotti>
    IRC <irc://irc.freenode.net/#kotti>
    Issues <https://github.com/Kotti/Kotti/issues>
    Twitter <https://twitter.com/KottiCMS>
